@@ -428,8 +428,7 @@ int ffgtcs(fitsfile *fptr,    /* I - FITS file pointer           */
        calculate celestial coordinates. (ffxypx, ffwldp)
 */
 {
-    char comm[FLEN_COMMENT],ctype[FLEN_VALUE],keynam[FLEN_KEYWORD];
-    int tstatus = 0, colnum[2];
+    int colnum[2];
     long naxes[2];
     fitsfile *tptr;
 
